# scalebaron
Python toolkit for composite visualization and scaling of elemental imaging data 

To install:
```{bash}
pip install git+https://github.com/twinmum1277/scalebaron
```

Or from PyPI:
```{bash}
pip install scalebaron
```

To run ScaleBaron: 
```{bash}
scalebaron
```

To run Muad'Data: 
```{bash}
muaddata
```

To download test data for this package:
```{bash}
download_test_elemental_images
```